@@ -16,13 +16,12 @@ Tuskar domain models for use with SQLAlchemy.
 """
 
 from oslo.config import cfg
+from oslo.db.sqlalchemy import models
 
 from sqlalchemy import (Column, ForeignKey, Integer, String, Text)
 from sqlalchemy.ext.declarative import declarative_base
 from sqlalchemy.orm import relationship
 
-from tuskar.openstack.common.db.sqlalchemy import models
-
 
 sql_opts = [
     cfg.StrOpt('mysql_engine',
