@@ -86,7 +86,13 @@ class DeploymentPlan(object):
         :param filename: name of the file where the template is stored, used
                          when mapping the template in the environment
         :type  filename: str
+        :raise ValueError: if given namespace is already taken
         """
+        if self.environment.has_parameter_in_namespace(namespace):
+            raise ValueError(
+                "Cannot add template to plan - namespace '%s' is taken."
+                % namespace)
+
         resource_alias = ns_utils.apply_resource_alias_namespace(namespace)
 
         self._add_to_master_template(namespace, template, resource_alias)
@@ -166,7 +172,7 @@ class DeploymentPlan(object):
         if self.add_scaling:
             count_param = Parameter(_generate_count_property_name(namespace),
                                     'number')
-            constraint = ParameterConstraint('range', {'min': 1})
+            constraint = ParameterConstraint('range', {'min': '1'})
             count_param.add_constraint(constraint)
             self.master_template.add_parameter(count_param)
 
@@ -193,7 +199,7 @@ class DeploymentPlan(object):
 
         if self.add_scaling:
             count_param_name = _generate_count_property_name(namespace)
-            count_param = EnvironmentParameter(count_param_name, 1)
+            count_param = EnvironmentParameter(count_param_name, '1')
             self.environment.add_parameter(count_param)
 
         # Add Resource Registry Entry
@@ -208,8 +214,15 @@ class DeploymentPlan(object):
         self.master_template.remove_outputs_by_namespace(namespace)
 
         # Remove Resource
+
+        # If scaling features are being automatically added in, the resource
+        # is wrapped in a scaling group, so remove that instead
         resource_id = _generate_resource_id(namespace)
-        self.master_template.remove_resource_by_id(resource_id)
+        if self.add_scaling:
+            group_resource_id = _generate_group_id(resource_id)
+            self.master_template.remove_resource_by_id(group_resource_id)
+        else:
+            self.master_template.remove_resource_by_id(resource_id)
 
     def _remove_from_environment(self, namespace):
         # Remove Parameters
