@@ -105,6 +105,18 @@ class DeploymentPlanTests(unittest.TestCase):
                          p2.name)
         self.assertEqual('', p2.value)
 
+    def test_add_template_with_colliding_namespace(self):
+        # Test
+        p = plan.DeploymentPlan()
+        p.environment.add_parameter(
+            heat.EnvironmentParameter('ns1::param-1', 'value-1'))
+        t = heat.Template()
+        t.add_parameter(heat.Parameter('param-2', 'type-1'))
+
+        # Verify
+        self.assertRaises(ValueError,
+                          p.add_template, 'ns1', t, 'template-1.yaml')
+
     def test_add_scaling_with_scaling(self):
         # Test
         p = plan.DeploymentPlan(add_scaling=True)
@@ -122,7 +134,7 @@ class DeploymentPlanTests(unittest.TestCase):
         const = count_param.constraints[0]
         self.assertTrue(isinstance(const, heat.ParameterConstraint))
         self.assertEqual(const.constraint_type, 'range')
-        self.assertEqual(const.definition, {'min': 1})
+        self.assertEqual(const.definition, {'min': '1'})
 
         # Verify Resource Group Wrapper
         self.assertEqual(1, len(p.master_template.resources))
@@ -146,7 +158,7 @@ class DeploymentPlanTests(unittest.TestCase):
         self.assertEqual(3, len(p.environment.parameters))
         count_param = p.environment.parameters[2]
         self.assertEqual(count_param.name, expected_count_name)
-        self.assertEqual(count_param.value, 1)
+        self.assertEqual(count_param.value, '1')
 
     def test_remove_template(self):
         # Setup & Sanity Check
